@@ -4,8 +4,8 @@
 # Python3
 from __future__ import unicode_literals
 
-__version__ = '1.1.0'
-__author__ = "Raphaël Barrois <raphael.barrois@polytechnique.org>"
+__version__ = '1.1.1'
+__author__ = "Raphaël Barrois <raphael.barrois+tdparser@polytechnique.org>"
 
 
 from .topdown import (
